#!/bin/sh

# Test with two parsers
#
NSGMLS="/valhalla/d1/ECIX/JCLARK/SP/sp-1.3/nsgmls/nsgmls"
SGMLNORM="/valhalla/d1/ECIX/JCLARK/SP/sp-1.3/sgmlnorm/sgmlnorm"

# Set options
#
ERR_OPTIONS="-eg"
WARN_OPTIONS="-wall"
XML_OPTIONS="-wxml"

# Set filenames
#
DATAOUT=dataout
ERROUT=dataerr
DICT_CATALOG=catalog.xml
DECLARATION=xml.dec
DECL_TMP=xmltmp.dec

INPUT_FILE=$1
if [ -z "$INPUT_FILE" ]
  then echo Use: runxml.sh XML-INSTANCE-PATH
       exit 1
  fi

INPUT_BASE=`basename $INPUT_FILE ".xml"`

TESTFILE=sample_fixed.xml
OPTIONS="$ARCH_OPTIONS $ERR_OPTIONS $WARN_OPTIONS $XML_OPTIONS"

##### Pre-process data file for spurious whitespace
#
# The XML instance has been nicely indented for human readability.
# However, this introduces whitespace into several content models.
# First delete all leading spaces, then the newlines to get rid of the
# spurious whitespace added to the instance during indentation for the
# purpose of readability.     
#
echo ""
echo "___Deleting leading spaces and newlines from indented $INPUT_FILE"
#sed "s/^ *//" $INPUT_FILE | tr -d "\012" >$TESTFILE
sed "s/^ *//" $INPUT_FILE >$TESTFILE

# Alter standard XML declaration: SP 1.3 only supports 16-bit characters.
#
sed "
/160     55136   160/{
s/160     55136   160/160     65374   160/
a\\
                65534   2       UNUSED
}
s/   55296   2048    UNUSED.*/-- 55296   2048    UNUSED/
s/65534   2       UNUSED.*/65534   2       UNUSED/
s/65536   1048576 65536/65536   1048576 65536 --/
" $DECLARATION >$DECL_TMP
#
# Create a temporary catalog to reference the altered XML declaration 
#
echo "SGMLDECL \"$DECL_TMP\"" >$DICT_CATALOG


##### Run test with nsgmls

PARSER=$NSGMLS

echo ""
echo ___Running parser $PARSER on test file $TESTFILE
echo "   Producing ESIS output in dataerr_nsgmls."

SGML_CATALOG_FILES=$DICT_CATALOG	\
	SP_CHARSET_FIXED=YES		\
	SP_ENCODING=XML			\
	$PARSER -f$ERROUT $OPTIONS $TESTFILE  >$DATAOUT

mv dataerr $INPUT_BASE.err_nsgmls
mv dataout $INPUT_BASE.out_nsgmls

#echo ___Checking error output log...
#if diff $ERROUT $ERROUT-xml.gold
#  then echo .....Test of $TESTFILE error output successful.
#  else echo .....Test of $TESTFILE error output failed.
#  fi
#
#echo ___Checking parse tree data output...
#if diff $DATAOUT $DATAOUT-xml.gold
#  then echo .....Test of $TESTFILE parse tree successful.
#  else echo .....Test of $TESTFILE parse tree failed.
#  fi


##### Run test with sgmlnorm

PARSER=$SGMLNORM

echo ""
echo ___Running parser $PARSER on test file $TESTFILE
echo "   Producing normalized XML markup output in dataout_sgmlnorm."
SGML_CATALOG_FILES=$DICT_CATALOG			\
	SP_CHARSET_FIXED=YES				\
	SP_ENCODING=XML					\
	$PARSER -f$ERROUT $OPTIONS $TESTFILE  >$DATAOUT

#echo ___Checking error output log...
#if sed "s/sgmlnorm/nsgmls/g" $ERROUT | diff - $ERROUT-xml.gold
#  then echo .....Test of $TESTFILE error output successful.
#  else echo .....Test of $TESTFILE error output failed.
#  fi
#
#echo ___Checking normalized XML data output...
#if diff $DATAOUT $DATAOUT-xml-norm.gold
#  then echo .....Test of $TESTFILE parse tree successful.
#  else echo .....Test of $TESTFILE parse tree failed.
#  fi

mv dataerr $INPUT_BASE.err_sgmlnorm
mv dataout $INPUT_BASE.out_sgmlnorm


##### Cleanup

echo ""
echo "___Removing generated $TESTFILE"
rm -f $TESTFILE $DECL_TMP $DICT_CATALOG

echo ""
